function [ modification_history ] = float_to_template_south( p_nemo_float, p_template, p_config, p_single_float )
%FLOAT_TO_TEMPLATE_SOUTH Plots the float positions to the given template. 
%
%   Parameters:
%   p_nemo_float:           The float data, can be more than one.
%   p_template:             The template generated by
%                           nemo.plots.templates.create_south function
%   p_config:               The nemo configuration.
%   p_single_float:         If true, just one float is being plotted to the
%                           template at a time. If false, all floats will
%                           be plotted into the plot.
%   
%   Returns:
%   modification_history:   The modifications made by this function to the
%                           template.

% make template the current figure
set(0, 'currentfigure', p_template);

% get style of plot
plot_style = p_config.PLOT_STYLE_SOUTH;

if p_single_float
    show_profile_numbers = p_config.PLOT_SINGLE_FLOAT_SOUTH.show_profile_numbers;
else
    show_profile_numbers = p_config.PLOT_OVERVIEW_SOUTH.show_profile_numbers;
end

modification_history = [];

profile_count = length(p_nemo_float);
bgp_lat = nan(profile_count, 1);
bgp_lon = nan(profile_count, 1);

% store the first position manually, because then its possible to save
% the source of the previous index
% best guess positions (abbr. bgp)
bgp_lat(1) = p_nemo_float{1}.SECOND_ORDER_INFORMATION.best_guess_position_lat;
bgp_lon(1) = p_nemo_float{1}.SECOND_ORDER_INFORMATION.best_guess_position_lon;
bgp_src{1} = p_nemo_float{1}.SECOND_ORDER_INFORMATION.best_guess_position_src;
profile_numbers(1, 1) = p_nemo_float{1}.PROFILE_TECHNICAL_DATA.xmit_profile_number;
measured_ranges = []; % ranges of measured positions will be stored in here

if (strcmp(bgp_src{1}, 'gps') || strcmp(bgp_src{1}, 'iridium'))
    % it is a measured position, so save the index!
    measured_start_index = 1;
else
    measured_start_index = 0; % because zero is not a valid index
end

for ii=2:profile_count
    
    % best guess positions (abbr. bgp)
    bgp_lat(ii) = p_nemo_float{ii}.SECOND_ORDER_INFORMATION.best_guess_position_lat;
    bgp_lon(ii) = p_nemo_float{ii}.SECOND_ORDER_INFORMATION.best_guess_position_lon;
    bgp_src{ii} = p_nemo_float{ii}.SECOND_ORDER_INFORMATION.best_guess_position_src;
    profile_numbers(ii, 1) = p_nemo_float{ii}.PROFILE_TECHNICAL_DATA.xmit_profile_number;
    
    % get all pairs of measured positions
    if (measured_start_index == 0) && (strcmp(bgp_src{ii}, 'gps') || strcmp(bgp_src{ii}, 'iridium'))
        % no starting index is set, but a measured position has been
        % found
        measured_start_index = ii;
    elseif (measured_start_index > 0) && ((~strcmp(bgp_src{ii}, 'gps') && ~strcmp(bgp_src{ii}, 'iridium')))
        % starting index valid, but a not measured position has been
        % found, so store endpoint
        measured_ranges = [measured_ranges; [measured_start_index ii-1]];
        measured_start_index = 0; % set invalid start index
    elseif ((measured_start_index > 0) && (ii == profile_count))
        % the last position is also valid
        measured_ranges = [measured_ranges; [measured_start_index ii]];
        measured_start_index = 0; % set invalid start index
    end
    
end

% draw all bgp positions first
modification_history(end+1) = plotm(bgp_lat,bgp_lon,'marker',plot_style.gps_marker,'markersize',plot_style.gps_markersize,'color',plot_style.gps_color_interpolated, 'linestyle', '-');   %  GPS positions

% get deployment position
dep_lat = p_nemo_float{1}.DEPLOYMENT_INFO.deployment_position(1);
dep_lon = p_nemo_float{1}.DEPLOYMENT_INFO.deployment_position(2);

if (~isempty(measured_ranges)) && (measured_ranges(1, 1) == 1) % first position is a measured position
    % plot a black line from deployment position to first profile
    % position
    modification_history(end+1) = plotm([dep_lat; bgp_lat(1)], [dep_lon; bgp_lon(1)],'marker',plot_style.gps_marker,'markersize',plot_style.gps_markersize,'color',plot_style.gps_color, 'linestyle', '-');   %  GPS positions
else
    % plot a interpolated line
    modification_history(end+1) = plotm([dep_lat; bgp_lat(1)], [dep_lon; bgp_lon(1)],'marker',plot_style.gps_marker,'markersize',plot_style.gps_markersize,'color',plot_style.gps_color_interpolated, 'linestyle', '-');
end

% draw all measured (iridium or gps) positions above it
measured_length = size(measured_ranges, 1);
for o_measured_index = 1:measured_length
    modification_history(end+1) = ...
    plotm(bgp_lat(measured_ranges(o_measured_index, 1):measured_ranges(o_measured_index, 2)), ...
        bgp_lon(measured_ranges(o_measured_index, 1):measured_ranges(o_measured_index, 2)), ...
        'marker',plot_style.gps_marker,...
        'markersize',plot_style.gps_markersize, ...
        'color', plot_style.gps_color, 'linestyle', '-');   %  GPS positions
end

% plot deployment position
modification_history(end+1) = plotm(dep_lat,dep_lon,150,'marker',plot_style.deploy_marker,'markersize',plot_style.deploy_markersize,'color',plot_style.deploy_color,'linestyle','none');   % plot deplyoment position as crossed square

% plot last transmittion
modification_history(end+1) = plotm(bgp_lat(end),bgp_lon(end),150,'marker',plot_style.gps_marker,'markersize',plot_style.gps_markersize,'color',plot_style.last_transmittion_color,'linestyle','none');    % plot final gps position
% plot serial number of float to the last transmitted profile
text_serial_number = textm(bgp_lat(end)+0.2,bgp_lon(end)+0.2,num2str(p_nemo_float{end}.FLOAT_IDENTIFICATION.float_serial_number));
set(text_serial_number,'interpreter','none', 'FontSize', 6,'FontWeight','bold');
modification_history(end+1) = text_serial_number;
clear measured_ranges measured_length measured_start_index profile_count text_serial_number

% change figure title
if p_single_float
    set(get(gca, 'title'), 'String', ['Float ' num2str(p_nemo_float{end}.FLOAT_IDENTIFICATION.float_serial_number) ', ' datestr(now) ]);
else
    set(get(gca, 'title'), 'String', datestr(now));
end


if show_profile_numbers == 1
    % plot profile numbers
    text_profile_numbers = textm(bgp_lat(10:10:end)+0.2,bgp_lon(10:10:end)+0.2,num2str(profile_numbers(10:10:end)));
    set(text_profile_numbers,'interpreter','none', 'FontSize', 6,'FontWeight','bold');
    if length(text_profile_numbers) > 1
        modification_history = [modification_history, text_profile_numbers'];
    elseif length(text_profile_numbers) == 1
        modification_history(end+1) = text_profile_numbers;
    end
end

clear bgp_lat bgp_lon dep_lat dep_lon bgp_src profile_numbers text_profile_numbers

end

